#
# spec file for package keepass
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _name KeePass

Name:           keepass
Version:        2.38
Release:        lp152.3.63
Summary:        Password Manager
License:        GPL-2.0+
Group:          Productivity/Other
Url:            https://keepass.info/
Source0:        https://netcologne.dl.sourceforge.net/project/keepass/KeePass%202.x/%{version}/KeePass-%{version}-Source.zip
Source1:        https://keepass.info/integrity/v2/KeePass-%{version}-Source.zip.asc
# http://keepass.info/integrity/Dominik_Reichl.asc
Source2:        keepass.keyring
BuildRequires:  dos2unix
BuildRequires:  mono-devel
BuildRequires:  unzip
BuildRequires:  xdotool-devel
BuildRequires:  xorg-x11-fonts-core
BuildRequires:  xsel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
KeePass is a password manager, which helps you to manage your
passwords. You can put all your passwords in one database, which is
locked with one master key or a key file, so that you only have to
remember one single master password or select the key file to unlock
the whole database. The databases are encrypted using AES and
Twofish.

%prep
%setup -q -c %{name}-%{version}
dos2unix Docs/License.txt Docs/History.txt

sed -i '1s/ 10.00/ 11.00/' KeePass.sln
find . -name "*.csproj" -exec sed -i '1s/"3.5"/"4.0"/' {} +

pushd Build &>/dev/null
bash PrepMonoDev.sh
sh PrepMonoDev.sh
popd &>/dev/null

%build
xbuild /target:KeePass /property:Configuration=Release

%install
install -d %{buildroot}%{_prefix}/lib/%{name}
install -d %{buildroot}%{_prefix}/lib/%{name}/XSL
install -m 644 Build/%{_name}Lib_Distrib/%{_name}Lib.dll %{buildroot}%{_prefix}/lib/%{name}/
install -m 644 Build/%{_name}/Release/%{_name}.exe* %{buildroot}%{_prefix}/lib/%{name}/
install -m 644 Ext/%{_name}.config.xml %{buildroot}%{_prefix}/lib/%{name}/
install -m 644 Ext/%{_name}.exe.config %{buildroot}%{_prefix}/lib/%{name}/
install -m 644 Ext/XSL/* %{buildroot}%{_prefix}/lib/%{name}/XSL

# Bin wrapper
install -d %{buildroot}%{_bindir}
cat << EOF > %{buildroot}%{_bindir}/%{name}
#!/bin/sh
exec mono %{_prefix}/lib/%{name}/%{_name}.exe "\$@"
EOF

# Desktop file
install -d %{buildroot}%{_datadir}/applications
cat << EOF > %{buildroot}%{_datadir}/applications/%{name}.desktop
[Desktop Entry]
Type=Application
Name=%{_name}
GenericName=Password Manager
Comment=Secure Password Management System
Icon=keepass
TryExec=%{_bindir}/keepass
Exec=keepass
Terminal=false
Categories=Utility;Security;
X-SuSE-translate=false
EOF

# Icon
install -d %{buildroot}%{_datadir}/pixmaps
install -m 644 Ext/Icons_04_CB/Finals/plock-blu.png %{buildroot}%{_datadir}/pixmaps/%{name}.png

%files
%defattr(-,root,root)
%doc Docs/License.txt Docs/History.txt
%attr(755,root,root) %{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png
%{_prefix}/lib/keepass

%changelog
* Wed Jan 10 2018 idonmez@suse.com
- Update to 2.38
  New features:
  * Added button 'Open Folder' in the language selection dialog,
    which opens the 'Languages' folder.
  * Added button 'Open Folder' in the plugins dialog,
    which opens the 'Plugins' folder.
  * Added option 'Icon' and an option for specifying the placeholder
    behavior (replace or not, or both forms) in the 'Print' / HTML
    export dialog.
  * Printing / HTML export: the notes of a group are now displayed
    below the group name.
  * Enhanced the Password Exporter import module to support XML
    files created by version 1.3.4.
  * Added workaround for Mono list view item deletion bug.
  * Added workaround for Mono command line argument encoding bug.
  Improvements:
  * Password quality estimation: improved compatibility with
    process memory protection.
  * Improved UI scaling when using KeePass on multiple systems
    with different DPI values.
  * Printing / HTML export: improved embedding of CSS.
  * Printing / HTML export: spaces in passwords are now encoded
    as non-breaking spaces.
  * Improved UI updating in the 'Print' / HTML export dialog.
  * Enhanced KDE system font detection.
  * Improved fatal error handling.
  * Various improvements in the language selection dialog.
  * Various code optimizations.
  * Minor other improvements.
  Bugfixes:
  * Fixed HTML generation bug: when the option 'Use monospace
    font for passwords' was turned off, a generated HTML file
    in 'Details' mode could contain invalid end tags
* Thu Oct 12 2017 idonmez@suse.com
- Update to 2.37
  New features:
  * When creating a new database, KeePass now offers to print a
    KeePass emergency sheet (which can then be filled out and
    stored in a secure location, where only the user and possibly
    a few other people that the user trusts have access to);
    an emergency sheet can also be created via
    'Tools' -> 'Database Tools' -> 'Print Emergency Sheet'.
  * Added database file information dialog that is displayed
    when creating a new database.
  * Added function to search similar password clusters
  ('Edit' -> 'Show Entries' -> 'Find Similar Passwords (Clusters)').
  * On Unix-like systems: if the library 'libgcrypt.so.20' is
    available, KeePass uses it for AES-KDF transformations.
  * Added workaround for .NET/Windows column header drawing bug
    when switching to TAN-only entry list mode.
  * Added workaround for Mono tab switching bug.
  * Added workaround for Mono '}' character RTF encoding bug.
  * TrlUtil: added support for .NET 4.*.
  Improvements:
  * Improved dialog for changing the master key
  * KeePass now directly offers to save the database after
    changing the master key, and it asks whether to print a
    new emergency sheet.
  * Various improvements in the translation selection dialog
  * KeePass now refuses to attach files that are larger than
    512 MB (as larger files can result in serialization problems).
  * Increased default number of AES-KDF rounds.
  * On Unix-like systems, KeePass now uses the CSP implementation
    of the AES algorithm for encrypting data, which is a bit faster.
  * Improved tool strip checkmark rendering on Unix-like systems.
* Sat Jun 10 2017 idonmez@suse.com
- Update to 2.36
  * See http://keepass.info/news/n170609_2.36.html for the
    complete changelog.
* Mon Jun  5 2017 idonmez@suse.com
- Fix install with Mono 5.0 (mdb files are not built anymore.)
* Fri May 19 2017 idonmez@suse.com
- Depend on mono-devel instead of monodevelop
* Mon Jan  9 2017 idonmez@suse.com
- Update to version 2.35
  * ChaCha20 and Argon2 support
  * See http://keepass.info/news/n170109_2.35.html for the changelog.
* Thu Dec 15 2016 jengelh@inai.de
- Trim filler words from description
* Sat Jun 11 2016 idonmez@suse.com
- Update to version 2.34
  * See http://keepass.info/news/n160611_2.34.html for details.
* Sat May  7 2016 idonmez@suse.com
- Update to 2.33
  * See http://keepass.info/news/n160507_2.33.html for the changelog.
* Thu Mar 10 2016 idonmez@suse.com
- Update to version 2.32
  * See http://keepass.info/news/n160309_2.32.html for the changelog.
- Remove Requires on libgdiplus-devel, this is fixed in Mono some
  time ago.
* Tue Jan 12 2016 t.gruner@katodev.de
- update to 2.31 (2016-01-09)
  - Added menu/toolbar styles, freely selectable in 'Tools' ->
    'Options' -> tab 'Interface'; available styles are 'Windows
    10', 'Windows 8.1', 'KeePass - Gradient', '.NET/Office -
    Professional' and 'System - Classic'; by default KeePass uses
    the style most similar to the one of the current operating
    system
  - Refined application icons (thanks to Victor Andreyenkov)
  - Auto-Type: new target window classification method, which
    improves compatibility with target windows hosted within
    other windows (e.g. a PuTTY window within SuperPuTTY/MTPuTTY)
  - Auto-Type: added workaround for the default Ctrl+Alt behavior
    of KiTTY variants (which differs from Windows' behavior)
  - Before clearing the clipboard, KeePass now first copies a
    non-sensitive text into it; this ensures that no sensitive
    information remains in the clipboard even when clearing is
    prevented by the environment (e.g. when running in a virtual
    machine, when using a clipboard extension utility, ...)
  - Added support for opening entry URLs with Internet Explorer
    or Google Chrome in private mode via the context menu ->
    'URL(s)' -> 'Open with ... (Private)'
  - Added URL override suggestions for Internet Explorer and
    Google Chrome in private mode in the URL override suggestions
    drop-down list in the entry dialog
  - Added optional built-in global URL overrides for opening
    HTTP/HTTPS URLs with Internet Explorer or Google Chrome in
    private mode
  - Added Ctrl+K shortcut for the 'Duplicate Entry' command
  - Mozilla Bookmarks HTML import: added support for importing
    tags
  - Added support for exporting to Mozilla Bookmarks HTML files
  - Windows/IE favorites export: entry fields are Spr-compiled
    now, and entries with cmd:// URLs are now exported as LNK
    files
  - HTML export/printing: added support for UUIDs, added
    horizontal lines between entries in details mode, added
    background color for group headings, long field names are
    hyphenated now, and long field data now breaks and wraps onto
    the next line
  - Plugins: added possibility to configure file transactions for
    each URI scheme
  - Plugins: added possibility to provide custom 'Save As'
    dialogs more easily
  - Converted some PNG images as a workaround for a problem in
    Cairo/LibPNG on Unix-like systems
  - As a workaround for a weakness in Mono's FileDialog, before
    showing such a dialog on Unix-like systems KeePass now tries
    to load the file '~/.recently-used' and deletes it, if it is
    not a valid XML file
  - KPScript: added support for specifying the master password in
    encrypted form using the '-pw-enc:' command line parameter
    (exactly like in KeePass, compatible with the {PASSWORD_ENC}
    placeholder)
  - KPScript: the 'Export' command now supports the optional
    '-GroupPath:' parameter (to export a specific group instead
    of the whole database)
  - KPScript: the 'GetEntryString' command now supports the
    '-FailIfNoEntry' option
  - KPScript: added '-refx-Expires' and '-refx-Expired' entry
    identification parameters
  - KPScript: the 'Import' command now prints more specific error
    messages
  - All KeePass program binaries are now dual signed using SHA-1
    and SHA-256
  - Auto-Type: improved keyboard layout handling when the target
    window changes during an auto-type process
  - Auto-Type: improved compatibility with Remote Desktop
    Connection client and VirtualBox
  - Improved icon recoloring
  - Improved printing of dates/times and tags
  - The password generator based on a character set now ensures
    that the generated password is Spr-invariant
  - Password generator based on a pattern or a custom algorithm:
    when a Spr-variant password is generated, a confirmation
    dialog for accepting this password is displayed
  - If the 'Save Database' policy prevents saving, the auto-save
    option is now ignored
  - Improved .NET Framework version detection
  - PLGX debugging: when the command line option '-debug' is
    passed and a PLGX plugin fails to compile, the output of all
    tried compilers is saved to a temporary file
  - Improved file transaction creation time handling on Unix-like
    systems
  - Improved compatibility with Mono on BSD systems
  - Enhanced PrepMonoDev.sh script for compatibility with Mono
    4.x
  - Removed KeePassLibSD sub-project (a KeePass library for
    Pocket PC / Windows Mobile) from the main solution
  - Upgraded installer
  - Various code optimizations
  - Minor other improvements
  - When running under Mono (Linux, Mac OS X, ...), two options
    related to window minimization are disabled now (because they
    do not work properly due to a Mono bug)
* Sun Sep  6 2015 t.gruner@katodev.de
- update to 2.30 (2015-08-09)
  - When opening a database via an URL fails, the error message
    dialog now has a button 'Specify different server
    credentials' (on Windows Vista and higher)
  - Added support for opening entry URLs with Microsoft Edge via
    the context menu -> 'URL(s)' -> 'Open with Edge'
  - Added URL override suggestion for Microsoft Edge in the URL
    override suggestions drop-down list in the entry dialog
  - Added optional built-in global URL overrides for opening
    HTTP/HTTPS URLs with Microsoft Edge
  - When clicking on a group link in the entry view, KeePass now
    ensures that the group is visible in the group tree
  - The main window is now moved onto the primary screen when it
    is restored outside all screens
  - KDBX loader: added support for non-empty protected binary
    value reference elements
  - Plugins: added two auto-type sequence query events
  - Added workaround for Mono drawing bug when scrolling a rich
    text box
  - When running under Mono, some automatic locking options are
    now disabled (because Mono doesn't implement the required
    events)
  - The installer now prevents running the installer while it is
    already running
  - KPScript: added '-GroupPath:' parameter (for specifying the
    full path of a group)
  - KPScript: the 'MoveEntry' command now also supports the
    '-GroupName:' parameter (as alternative to '-GroupPath:')
  - KPScript: added support for specifying the path of an XSL
    stylesheet file using the command line parameter '-XslFile:'
  - KPScript: the 'ListGroups' command now also outputs the
    parent group UUID for each group
  - KPScript: the parameters for specifying new field data (for
    the 'AddEntry' and the 'EditEntry' command) now support
    escape sequences (e.g. '\n' is replaced by a new-line
    character)
  - The 'Synchronize' file dialog now shows only KDBX files by
    default
  - In the 'Attachments (Count)' column, only non-zero counts are
    shown now
  - Improved MRU item refreshes
  - The entry string dialog now supports changing the case of a
    string name
  - The entry string dialog now does not allow adding a string
    whose name differs from another existing string name in this
    entry only by case
  - The entry view in the main window is now updated immediately
    after pressing Ctrl+H or Ctrl+J
  - The KDB import module now tries to round any invalid
    date/time to the nearest valid date/time
  - XML serializers are now loaded/created at KeePass startup in
    order to avoid a problem when shutting down Windows and
    KeePass.XmlSerializers.dll not being present
  - Changed tab bar behavior in the options dialog to avoid a tab
    content cropping issue caused by plugins
  - Improved workaround for Mono splitter bug
  - Upgraded installer
  - Various performance improvements
  - Various code optimizations
  - Minor other improvements
* Thu Apr 30 2015 t.gruner@katodev.de
- fix GPG validation
* Sat Apr 11 2015 mailaender@opensuse.org
- fix System.DllNotFoundException: libgdiplus.so
- don't use _service (not allowed in Factory)
- add GPG validation source file integrity checks
- update to 2.29
  * http://keepass.info/news/n150410_2.29.html
  * http://keepass.info/news/n141008_2.28.html
* Mon Jul 14 2014 altesholz@gmail.com
- update to 2.27
  - Changelog: http://keepass.info/news/n140706_2.27.html
* Sat May 10 2014 chris+dev@any.mx
- update to 2.26
  - Changelog: http://keepass.info/news/n140413_2.26.html
* Fri Feb 28 2014 chris+dev@any.mx
- update to 2.25
  - Changelog: http://keepass.info/news/n140203_2.25.html
- added download service
* Thu Jan 30 2014 peter.trommler@ohm-hochschule.de
- update to 2.24
- fix for broken png files
  * drop extra file with png images
- for changelog see: http://keepass.info/news/n131103_2.24.html
* Wed Oct 23 2013 peter.trommler@ohm-hochschule.de
- add archive with fixed png files (see bug #1168)
- remove dependency on pngcrush
* Sun Oct 20 2013 peter.trommler@ohm-hochschule.de
- update to 2.23
- fix png files (see https://bugs.gentoo.org/show_bug.cgi?id=472764)
* Sun Mar 10 2013 mailaender@opensuse.org
- update to 2.21
  - Changelog: http://keepass.info/news/n130203_2.21.html
- enable additional support for auto-type and clipboard operations
* Fri Oct 19 2012 adam@mizerski.pl
- update to 2.20.1
  - Improved support for images with DPI resolutions different from
    the DPI resolution of the display device.
  - {GOOGLECHROME} placeholder: updated detection code to also
    support the latest versions of Chrome.
  - The option to lock on remote control mode changes now
    additionally watches for remote connects and disconnects.
  - Improved Windows registry accesses.
  - Improved behavior when the user deletes the system temporary
    directory.
  - On Unix-like systems, KeePass now stores most of its temporary
    files in a private temporary directory (preferably in
    $XDG_RUNTIME_DIR).
  - Added detection support for the following web browsers on
    Unix-like systems: Rekonq, Midori and Dooble.
  - KeePass does not try to set the WM_CLASS property on Mac OS X
    systems anymore.
  - Modified some icons to work around unsupported PNG transparency
    keys in Mono.
  - Various code optimizations.
  - Minor other improvements.
* Sun Sep 30 2012 adam@mizerski.pl
- update to 2.20
* Thu Mar 11 2010 ajorgensen@novell.com
- Update to 2.10
